VLCServer class

Constructors

VLCServer({required String ipAddress, String vlcPort = "8080", required String? vlcPassword})

Properties

hashCode int
The hash code for this object.
no setterinherited
ipAddress String
getter/setter pair
isDefault bool
getter/setter pair
isPreviouslyConnected bool
getter/setter pair
name String
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
vlcHomeFolderPath String
getter/setter pair
vlcPassword String?
getter/setter pair
vlcPort String
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited